@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate test stubs for methods and functions
 
-our $VERSION = '0.0401';
+our $VERSION = '0.0500';
 
 use Moo;
 use strictures 2;
@@ -31,15 +31,21 @@ sub _build_name {
 }
 
 
-sub gather_methods {
+has subs => (
+    is       => 'rw',
+    init_arg => undef,
+);
+
+
+sub gather_subs {
     my ($self) = @_;
 
     my $sniff = Class::Sniff->new({ class => $self->module });
-    my @methods = $sniff->methods;
-    my %methods;
-    @methods{@methods} = undef;
+    my @subs = $sniff->methods;
+    my %subs;
+    @subs{@subs} = undef;
 
-    return \%methods;
+    $self->subs( \%subs );
 }
 
 
@@ -55,9 +61,12 @@ sub unit_test {
             . "\n"
             . 'isa_ok $obj, "' . $self->module . '";';
     }
-    else {
+    elsif ( grep { $_ eq 'new' } keys %{ $self->subs } ) {
         $test = 'ok $obj->can("' . $subroutine . '"), "' . $subroutine . '";';
     }
+    else {
+        $test = "ok $subroutine(), " . '"' . $subroutine . '";';
+    }
 
     return $test;
 }
@@ -76,17 +85,18 @@ use Test::More;
 
 END
 
-    my $methods = $self->gather_methods;
+    # Set the subs attribute
+    $self->gather_subs;
 
-    if ( exists $methods->{new} ) {
-        delete $methods->{new};
+    if ( exists $self->subs->{new} ) {
         my $test = $self->unit_test('new');
         $text .= "$test\n\n";
     }
 
-    for my $method ( sort keys %$methods ) {
-        next if $method =~ /^_/;
-        my $test = $self->unit_test($method);
+    for my $sub ( sort keys %{ $self->subs } ) {
+        next if $sub =~ /^_/;
+        next if $sub eq 'new';
+        my $test = $self->unit_test($sub);
         $text .= "$test\n\n";
     }
 
@@ -110,7 +120,7 @@ Test::NaiveStubs - Generate test stubs for methods and functions
 
 =head1 VERSION
 
-version 0.0401
+version 0.0500
 
 =head1 SYNOPSIS
 
@@ -147,6 +157,13 @@ The module name to use in the test generation.
 The test output file name.  If not given in the constructor, the filename is
 created from the B<module>.  So C<Foo::Bar> would be converted to C<foo-bar.t>.
 
+=head2 subs
+
+  $subs = $tns->subs;
+
+The subroutines in the given B<module>.  This is a computed attribute and as
+such, constructor arguments will be ignored.
+
 =head1 METHODS
 
 =head2 new()
@@ -155,12 +172,12 @@ created from the B<module>.  So C<Foo::Bar> would be converted to C<foo-bar.t>.
 
 Create a new C<Test::NaiveStubs> object.
 
-=head2 gather_methods()
+=head2 gather_subs()
 
-  $methods = $tns->gather_methods;
+  $tns->gather_subs;
 
-Return the methods of the given B<module> (as well as imported methods) as a
-hash reference.
+Set the B<subs> attribute to the subroutines of the given B<module> (as well as
+imported methods) as a hash reference.
 
 =head2 unit_test()
 
@@ -176,7 +193,8 @@ Create a test file with unit tests for each method.
 
 A C<new> method is extracted and processed first with C<use_ok>, object
 instantiation, followed by C<isa_ok>.  Then each seen method is returned as
-an ok can("method") assertion.
+an ok can("method") assertion.  If no C<new> method is present, an C<ok> with
+the subroutine is produced.
 
 =head1 SEE ALSO
 
